pytilities.delegation — Pytilities 1.2.0 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Pytilities 1.2.0 documentation »
- API documentation »
- pytilities »

# pytilities.delegation

Delegation utilities

These utilities are a front-end to the aop package.

Contents

- DelegationAspect
- mapped_class()
- mapped()

### Navigation

- index
- modules |
- next |
- previous |
- Pytilities 1.2.0 documentation »
- API documentation »
- pytilities »